==> test-support-1.2.1-sources.jar: com/xebialabs/deployit/test/support/utils/DebugStepExecutionContext.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of Xebialabs Software and Documentation is subject to the Personal
 * License Agreement.
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * ‚ÄúDocumentation‚Äù means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the Xebialabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.test.support.utils;

import com.xebialabs.deployit.StepExecutionContext;

public class DebugStepExecutionContext implements StepExecutionContext {
	private String lastStepOutput = "";
	private String lastStepError = "";

	public void logOutput(String output) {
		if (output.startsWith(lastStepOutput)) {
			System.err.println(output.substring(lastStepOutput.length()));
		} else {
			System.err.println(output);
		}
		lastStepOutput = output;
	}

	public void logError(String error) {
		if (error.startsWith(lastStepError)) {
			System.err.println(error.substring(lastStepError.length()));
		} else {
			System.err.println(error);
		}
		lastStepError = error;
	}

}

==> test-support-1.2.2-sources.jar: com/xebialabs/deployit/test/support/utils/DebugStepExecutionContext.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.test.support.utils;

import java.util.HashMap;
import java.util.Map;

import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.StepExecutionContextListener;

public class DebugStepExecutionContext implements StepExecutionContext {

	private Map<String, Object> attributes = new HashMap<String, Object>();

	public void logOutput(String output) {
		System.err.println(output);
	}

	public void logError(String error) {
		System.err.println(error);
	}

	public Object getAttribute(String name) {
		return attributes.get(name);
	}

	public void setAttribute(String name, Object object) {
		attributes.put(name, object);
	}

	public void destroy() {
		for (Object value : attributes.values()) {
			if (value instanceof StepExecutionContextListener) {
				((StepExecutionContextListener) value).contextDestroyed();
			}
		}
	}

}
